@@ -1,6 +1,6 @@
 /* ltdl.c -- system independent dlopen wrapper
 
-   Copyright (C) 1998-2000, 2004-2008, 2011-2013 Free Software
+   Copyright (C) 1998-2000, 2004-2008, 2011-2014 Free Software
    Foundation, Inc.
    Written by Thomas Tanner, 1998
 
@@ -1240,7 +1240,7 @@ try_dlopen (lt_dlhandle *phandle, const char *filename, const char *ext,
 	  goto cleanup;
 	}
 
-      strncpy (dir, canonical, dirlen);
+      strlcpy (dir, canonical, dirlen);
       dir[dirlen] = LT_EOS_CHAR;
 
       ++base_name;
